from smarkets.streaming_api import eto, seto  # noqa
from smarkets.streaming_api.client import StreamingAPIClient  # noqa
from smarkets.streaming_api.exceptions import (  # noqa
    ConnectionError, DecodeError, ParseError, SocketDisconnected, InvalidCallbackError)
from smarkets.streaming_api.session import Session, SessionSettings  # noqa
from smarkets.streaming_api.seto import IMMEDIATE_OR_CANCEL, GOOD_TIL_CANCELLED  # noqa

SIDE_BID = seto.SIDE_BUY
SIDE_OFFER = seto.SIDE_SELL
